pub struct TrayIconBuilder { /* private fields */ }Expand description
Builder for creating tray icons with custom internal window names.
Implementations
Sourceimpl TrayIconBuilder
impl TrayIconBuilder
Sourcepub fn new(id: TrayIconId, tooltip: impl Into<String>) -> Self
pub fn new(id: TrayIconId, tooltip: impl Into<String>) -> Self
Create a new tray icon builder with default class and window names.
Sourcepub fn owner_window(self, owner: WindowHandle) -> Self
pub fn owner_window(self, owner: WindowHandle) -> Self
Bind the tray icon to an existing owner window.
When set, custom class and window names are ignored because this builder does not create an internal message-only window.
Sourcepub fn window_class_name(self, name: impl Into<String>) -> Self
pub fn window_class_name(self, name: impl Into<String>) -> Self
Set the class name used when creating an internal message-only tray window.
Sourcepub fn window_name(self, name: impl Into<String>) -> Self
pub fn window_name(self, name: impl Into<String>) -> Self
Set the window name used when creating an internal message-only tray window.