Event rendering with publisher metadata caching.
Functions
- format_
message - Format a message for an event using provider metadata.
- render_
event - Render an event from a handle with selected format.
Event rendering with publisher metadata caching.