pub fn builder() -> RawFileBuilderExpand description
Create a raw file builder.
Use this for advanced tuning such as cluster read size and metadata buffer sizing.
pub fn builder() -> RawFileBuilderCreate a raw file builder.
Use this for advanced tuning such as cluster read size and metadata buffer sizing.