Module service

Module service 

Windows Service Control Manager operations.

This module provides ergonomic wrappers around the Windows Service Control Manager (SCM) APIs for querying and controlling services.

Structs

Service
Handle to an opened Windows service.
ServiceManager
Handle to the Windows Service Control Manager.
ServiceStatus
Runtime status for a Windows service.

Enums

ServiceAccess
Access rights for opening an individual Windows service.
ServiceControl
Service control codes that can be sent to a service.
ServiceManagerAccess
Access rights for opening a Service Control Manager handle.
ServiceState
Service state as reported by the Windows Service Control Manager.

Functions

list
List all services.
list_with_buffer
List all services using a reusable output buffer.
list_with_filter
List matching services using a reusable output buffer.
query
Query a service status by name.
restart
Restart a service by name, waiting for stopped state before start.
start
Start a service by name.
stop
Stop a service by name.