pub fn list_with_buffer(out_services: &mut Vec<ServiceStatus>) -> Result<usize>Expand description
List all services using a reusable output buffer.
Returns the number of services added to the output buffer.
pub fn list_with_buffer(out_services: &mut Vec<ServiceStatus>) -> Result<usize>List all services using a reusable output buffer.
Returns the number of services added to the output buffer.