Service

Struct Service 

pub struct Service { /* private fields */ }
Handle to an opened Windows service.

Implementations

Source

impl Service

pub fn open(name: &str) -> Result<Self>

Open a service by name using default access rights.

pub fn open_with_access(name: &str, access: ServiceAccess) -> Result<Self>

Open a service by name with explicit access rights.

pub fn name(&self) -> &str

Service key name.

pub fn query(&self) -> Result<ServiceStatus>

Query current service status.

pub fn query_with_buffer( &self, work_buffer: &mut Vec<u8>, ) -> Result<ServiceStatus>

Query current service status using a reusable workspace buffer.

pub fn start(&self) -> Result<()>

Start the service.

pub fn stop(&self) -> Result<()>

Stop the service.

pub fn send_control(&self, control: ServiceControl) -> Result<()>

Send a control code to the service.

pub fn restart(&self, timeout: Duration) -> Result<()>

Restart the service by waiting for stopped state and then starting it.