ServiceManager

Struct ServiceManager 

pub struct ServiceManager { /* private fields */ }
Handle to the Windows Service Control Manager.

Implementations

Source

impl ServiceManager

pub fn connect() -> Result<Self>

Open a service manager handle with default connect + enumeration rights.

pub fn connect_with_access(access: ServiceManagerAccess) -> Result<Self>

Open a service manager handle with explicit access rights.

pub fn open(&self, name: &str) -> Result<Service>

Open a service by name with default access (query/start/stop/pause-continue).

pub fn open_with_access( &self, name: &str, access: ServiceAccess, ) -> Result<Service>

Open a service by name with explicit access rights.

pub fn list(&self) -> Result<Vec<ServiceStatus>>

Enumerate all services.

pub fn list_with_buffer( &self, out_services: &mut Vec<ServiceStatus>, ) -> Result<usize>

Enumerate all services into a reusable output buffer.

pub fn list_with_filter<F>( &self, out_services: &mut Vec<ServiceStatus>, filter: F, ) -> Result<usize>
where F: Fn(&ServiceStatus) -> bool,

Enumerate services into a reusable output buffer, filtered during enumeration.