pub struct NamedPipePoller { /* private fields */ }Expand description
Stateful helper that diffs successive named-pipe snapshots.
Implementations
Sourceimpl NamedPipePoller
impl NamedPipePoller
Sourcepub fn poll(&mut self) -> Result<Vec<NamedPipeChange>>
pub fn poll(&mut self) -> Result<Vec<NamedPipeChange>>
Replace the current baseline with the latest snapshot and return detected changes.
Sourcepub fn seed(&mut self) -> Result<usize>
pub fn seed(&mut self) -> Result<usize>
Seed the baseline from the current snapshot without reporting any changes.
Sourcepub fn poll_interval(
&mut self,
rounds: usize,
interval: Duration,
) -> Result<Vec<Vec<NamedPipeChange>>>
pub fn poll_interval( &mut self, rounds: usize, interval: Duration, ) -> Result<Vec<Vec<NamedPipeChange>>>
Poll for a fixed number of rounds with a sleep interval between rounds.