Windows Service Control Manager operations.
This module provides ergonomic wrappers around the Windows Service Control Manager (SCM) APIs for querying and controlling services.
Structs
- Service
- Handle to an opened Windows service.
- Service
Manager - Handle to the Windows Service Control Manager.
- Service
Status - Runtime status for a Windows service.
Enums
- Service
Access - Access rights for opening an individual Windows service.
- Service
Control - Service control codes that can be sent to a service.
- Service
Manager Access - Access rights for opening a Service Control Manager handle.
- Service
State - Service state as reported by the Windows Service Control Manager.
Functions
- list
- List all services.
- list_
with_ buffer - List all services using a reusable output buffer.
- list_
with_ filter - List matching services using a reusable output buffer.
- query
- Query a service status by name.
- restart
- Restart a service by name, waiting for stopped state before start.
- start
- Start a service by name.
- stop
- Stop a service by name.