pub struct Service { /* private fields */ }Expand description
Handle to an opened Windows service.
Implementations
Sourceimpl Service
impl Service
Sourcepub fn open_with_access(name: &str, access: ServiceAccess) -> Result<Self>
pub fn open_with_access(name: &str, access: ServiceAccess) -> Result<Self>
Open a service by name with explicit access rights.
Sourcepub fn query(&self) -> Result<ServiceStatus>
pub fn query(&self) -> Result<ServiceStatus>
Query current service status.
Sourcepub fn query_with_buffer(
&self,
work_buffer: &mut Vec<u8>,
) -> Result<ServiceStatus>
pub fn query_with_buffer( &self, work_buffer: &mut Vec<u8>, ) -> Result<ServiceStatus>
Query current service status using a reusable workspace buffer.
Sourcepub fn send_control(&self, control: ServiceControl) -> Result<()>
pub fn send_control(&self, control: ServiceControl) -> Result<()>
Send a control code to the service.